==> flink-2.0.1-src.tgz: flink-2.0.1/flink-table/flink-table-planner/src/main/java/org/apache/flink/table/planner/plan/nodes/exec/serde/ChangelogModeJsonDeserializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.plan.nodes.exec.serde;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.connector.ChangelogMode;
import org.apache.flink.types.RowKind;

import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.core.JsonParser;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.DeserializationContext;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.JsonNode;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.deser.std.StdDeserializer;

import java.io.IOException;

/**
 * JSON deserializer for {@link ChangelogMode}.
 *
 * @see ChangelogModeJsonSerializer for the reverse operation
 */
@Internal
final class ChangelogModeJsonDeserializer extends StdDeserializer<ChangelogMode> {
    private static final long serialVersionUID = 1L;

    ChangelogModeJsonDeserializer() {
        super(ChangelogMode.class);
    }

    @Override
    public ChangelogMode deserialize(
            JsonParser jsonParser, DeserializationContext deserializationContext)
            throws IOException {
        ChangelogMode.Builder builder = ChangelogMode.newBuilder();
        JsonNode rowKindsNode = jsonParser.readValueAsTree();
        for (JsonNode rowKindNode : rowKindsNode) {
            RowKind rowKind = RowKind.valueOf(rowKindNode.asText().toUpperCase());
            builder.addContainedKind(rowKind);
        }
        return builder.build();
    }
}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-table/flink-table-planner/src/main/java/org/apache/flink/table/planner/plan/nodes/exec/serde/ChangelogModeJsonDeserializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.plan.nodes.exec.serde;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.connector.ChangelogMode;
import org.apache.flink.types.RowKind;

import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.core.JsonParser;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.DeserializationContext;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.JsonNode;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.deser.std.StdDeserializer;

import java.io.IOException;
import java.util.Objects;

/**
 * JSON deserializer for {@link ChangelogMode}.
 *
 * @see ChangelogModeJsonSerializer for the reverse operation
 */
@Internal
final class ChangelogModeJsonDeserializer extends StdDeserializer<ChangelogMode> {
    private static final long serialVersionUID = 1L;
    private static final String PARTIAL_DELETE = "~" + RowKind.DELETE.name();

    ChangelogModeJsonDeserializer() {
        super(ChangelogMode.class);
    }

    @Override
    public ChangelogMode deserialize(
            JsonParser jsonParser, DeserializationContext deserializationContext)
            throws IOException {
        ChangelogMode.Builder builder = ChangelogMode.newBuilder();
        JsonNode rowKindsNode = jsonParser.readValueAsTree();
        for (JsonNode rowKindNode : rowKindsNode) {
            final String rowKindText = rowKindNode.asText();
            if (Objects.equals(PARTIAL_DELETE, rowKindText)) {
                builder.keyOnlyDeletes(true);
                builder.addContainedKind(RowKind.DELETE);
            } else {
                RowKind rowKind = RowKind.valueOf(rowKindText);
                builder.addContainedKind(rowKind);
            }
        }
        return builder.build();
    }
}
